@@ -21,9 +21,23 @@ CATEGORY_SORTS = ('name', 'popularity', 'rating')  # This has to be a tuple not
 
 class Tag:
 
-    __slots__ = ('name', 'original_name', 'id', 'count', 'state', 'is_hierarchical',
-            'is_editable', 'is_searchable', 'id_set', 'avg_rating', 'sort',
-            'use_sort_as_name', 'category', 'search_expression', 'original_categories')
+    __slots__ = (
+        'avg_rating',
+        'category',
+        'count',
+        'id',
+        'id_set',
+        'is_editable',
+        'is_hierarchical',
+        'is_searchable',
+        'name',
+        'original_categories',
+        'original_name',
+        'search_expression',
+        'sort',
+        'state',
+        'use_sort_as_name',
+    )
 
     def __init__(self, name, id=None, count=0, state=0, avg=0, sort=None,
                  category=None, id_set=None, search_expression=None,
@@ -46,8 +60,7 @@ class Tag:
 
     @property
     def string_representation(self):
-        return '%s:%s:%s:%s:%s:%s'%(self.name, self.count, self.id, self.state,
-                                    self.category, self.original_categories)
+        return f'{self.name}:{self.count}:{self.id}:{self.state}:{self.category}:{self.original_categories}'
 
     def __str__(self):
         return self.string_representation
@@ -83,11 +96,18 @@ def create_tag_class(category, fm):
     is_editable = category not in {'news', 'rating', 'languages', 'formats',
                                    'identifiers'} and dt != 'composite'
 
-    if (tweaks['categories_use_field_for_author_name'] == 'author_sort' and
+    if (
+        (
             (category == 'authors' or
                 (cat['display'].get('is_names', False) and
-                cat['is_custom'] and cat['is_multiple'] and
-                dt == 'text'))):
+                 cat['is_custom'] and cat['is_multiple'] and
+                 dt == 'text')
+            ) and tweaks['categories_use_field_for_author_name'] == 'author_sort'
+        ) or (
+            dt == 'series' and
+            tweaks['categories_use_field_for_series_name'] == 'series_sort'
+        )
+       ):
         use_sort_as_name = True
     else:
         use_sort_as_name = False
@@ -175,6 +195,7 @@ def sort_key_for_name_and_first_letter(x, hierarchical_categories=()):
     return (c if numeric_collation and c.isdigit() else '9999999999',
             collation_order(v2), sort_key(v1))
 
+
 def sort_key_for_name(x, hierarchical_categories=()):
     v = x.sort or x.name
     if x.category not in hierarchical_categories:
@@ -279,7 +300,7 @@ def get_categories(dbcache, sort='name', book_ids=None, first_letter_sort=False,
         # temporarily duplicating the categories lists.
         taglist = {}
         for c, items in iteritems(categories):
-            taglist[c] = dict(map(lambda t:(icu_lower(t.name), t), items))
+            taglist[c] = {icu_lower(t.name): t for t in items}
 
         # Add the category values to the user categories
         for user_cat in sorted(user_categories, key=sort_key):
