@@ -11,6 +11,7 @@ from functools import partial
 
 from qt.core import (
     QAction,
+    QApplication,
     QDialog,
     QDialogButtonBox,
     QFrame,
@@ -124,14 +125,14 @@ class MetadataSingleDialogBase(QDialog):
         self.next_button = QPushButton(QIcon.ic('forward.png'), _('Next'),
                 self)
         self.next_action = ac = QAction(self)
-        ac.triggered.connect(self.next_clicked)
+        ac.triggered.connect(self.next_if_possible)
         self.addAction(ac)
         ac.setShortcut(QKeySequence('Alt+Right'))
         self.next_button.clicked.connect(self.next_clicked)
         self.prev_button = QPushButton(QIcon.ic('back.png'), _('Previous'), self)
         self.prev_button.clicked.connect(self.prev_clicked)
         self.prev_action = ac = QAction(self)
-        ac.triggered.connect(self.prev_clicked)
+        ac.triggered.connect(self.prev_if_possible)
         ac.setShortcut(QKeySequence('Alt+Left'))
         self.addAction(ac)
         from calibre.gui2.actions.edit_metadata import DATA_FILES_ICON_NAME
@@ -231,7 +232,7 @@ class MetadataSingleDialogBase(QDialog):
         self.swap_title_author_button = QToolButton(self)
         self.swap_title_author_button.setIcon(QIcon.ic('swap.png'))
         self.swap_title_author_button.setToolTip(_(
-            'Swap the author and title') + ' [%s]' % self.swap_title_author_shortcut.key().toString(QKeySequence.SequenceFormat.NativeText))
+            'Swap the author and title') + f' [{self.swap_title_author_shortcut.key().toString(QKeySequence.SequenceFormat.NativeText)}]')
         self.swap_title_author_button.clicked.connect(self.swap_title_author)
         self.swap_title_author_shortcut.activated.connect(self.swap_title_author_button.click)
 
@@ -239,7 +240,7 @@ class MetadataSingleDialogBase(QDialog):
         self.manage_authors_button.setIcon(QIcon.ic('user_profile.png'))
         self.manage_authors_button.setToolTip('<p>' + _(
             'Open the Manage Authors editor. Use to rename authors and correct '
-            'individual author\'s sort values') + '</p>')
+            "individual author's sort values") + '</p>')
         self.manage_authors_button.clicked.connect(self.authors.manage_authors)
 
         self.series_editor_button = QToolButton(self)
@@ -399,6 +400,10 @@ class MetadataSingleDialogBase(QDialog):
         else:
             self.view_format.emit(self.book_id, fmt)
 
+    def do_open_book_folder(self):
+        from calibre.gui2.ui import get_gui
+        get_gui().iactions['View'].view_folder_for_id(self.book_id)
+
     def do_edit_format(self, path, fmt):
         if self.was_data_edited:
             from calibre.gui2.tweak_book import tprefs
@@ -460,11 +465,11 @@ class MetadataSingleDialogBase(QDialog):
     def update_window_title(self, *args):
         title = self.title.current_val
         if len(title) > 50:
-            title = title[:50] + '\u2026'
+            title = title[:50] + '…'
         self.setWindowTitle(BASE_TITLE + ' - ' +
                 title + ' -' +
                 _(' [%(num)d of %(tot)d]')%dict(num=self.current_row+1,
-                tot=len(self.row_list)))
+                tot=len(self.id_list)))
 
     def swap_title_author(self, *args):
         title = self.title.current_val
@@ -611,6 +616,7 @@ class MetadataSingleDialogBase(QDialog):
             if d.cover_pixmap is not None:
                 self.metadata_before_fetch['cover'] = self.cover.current_val
                 self.cover.current_val = pixmap_to_data(d.cover_pixmap)
+        self.update_data_files_button()
 
     def undo_fetch_metadata(self):
         if self.metadata_before_fetch is None:
@@ -636,6 +642,7 @@ class MetadataSingleDialogBase(QDialog):
         if ret == QDialog.DialogCode.Accepted:
             if d.cover_pixmap is not None:
                 self.cover.current_val = pixmap_to_data(d.cover_pixmap)
+        self.update_data_files_button()
 
     # }}}
 
@@ -667,7 +674,7 @@ class MetadataSingleDialogBase(QDialog):
                 widget.commit(self.db, self.book_id)
                 self.books_to_refresh |= getattr(widget, 'books_to_refresh', set())
             except OSError as e:
-                e.locking_violation_msg = _('Could not change on-disk location of this book\'s files.')
+                e.locking_violation_msg = _("Could not change on-disk location of this book's files.")
                 raise
         for widget in getattr(self, 'custom_metadata_widgets', []):
             self.books_to_refresh |= widget.commit(self.book_id)
@@ -683,8 +690,8 @@ class MetadataSingleDialogBase(QDialog):
         self.save_state()
         if not self.apply_changes():
             return
-        if self.editing_multiple and self.current_row != len(self.row_list) - 1:
-            num = len(self.row_list) - 1 - self.current_row
+        if self.editing_multiple and self.current_row != len(self.id_list) - 1:
+            num = len(self.id_list) - 1 - self.current_row
             from calibre.gui2 import question_dialog
             pm = ngettext('There is another book to edit in this set.',
                           'There are still {} more books to edit in this set.', num).format(num)
@@ -718,7 +725,7 @@ class MetadataSingleDialogBase(QDialog):
     # Dialog use methods {{{
     def start(self, row_list, current_row, view_slot=None, edit_slot=None,
             set_current_callback=None):
-        self.row_list = row_list
+        self.id_list = list(map(self.db.id, row_list))
         self.current_row = current_row
         if view_slot is not None:
             self.view_format.connect(view_slot)
@@ -730,6 +737,18 @@ class MetadataSingleDialogBase(QDialog):
         self.break_cycles()
         return ret
 
+    def next_if_possible(self):
+        if self.next_button.isEnabled():
+            self.next_clicked()
+        else:
+            QApplication.beep()
+
+    def prev_if_possible(self):
+        if self.prev_button.isEnabled():
+            self.prev_clicked()
+        else:
+            QApplication.beep()
+
     def next_clicked(self):
         fw = self.focusWidget()
         if not self.apply_changes():
@@ -753,9 +772,9 @@ class MetadataSingleDialogBase(QDialog):
         self.update_window_title()
         prev = next_ = None
         if self.current_row > 0:
-            prev = self.db.title(self.row_list[self.current_row-1])
-        if self.current_row < len(self.row_list) - 1:
-            next_ = self.db.title(self.row_list[self.current_row+1])
+            prev = self.db.new_api.field_for('title', self.id_list[self.current_row-1])
+        if self.current_row < len(self.id_list) - 1:
+            next_ = self.db.new_api.field_for('title', self.id_list[self.current_row+1])
 
         if next_ is not None:
             tip = _('Save changes and edit the metadata of {0} [{1}]').format(
@@ -769,7 +788,7 @@ class MetadataSingleDialogBase(QDialog):
         self.prev_button.setEnabled(prev is not None)
         self.button_box.button(QDialogButtonBox.StandardButton.Ok).setDefault(True)
         self.button_box.button(QDialogButtonBox.StandardButton.Ok).setFocus(Qt.FocusReason.OtherFocusReason)
-        self(self.db.id(self.row_list[self.current_row]))
+        self(self.id_list[self.current_row])
         for w, state in iteritems(self.comments_edit_state_at_apply):
             if state == 'code':
                 w.tab = 'code'
@@ -822,7 +841,7 @@ class MetadataSingleDialog(MetadataSingleDialogBase):  # {{{
         self.tabs = []
         self.labels = []
         self.tabs.append(QWidget(self))
-        self.central_widget.addTab(ScrollArea(self.tabs[0], self), _("&Basic metadata"))
+        self.central_widget.addTab(ScrollArea(self.tabs[0], self), _('&Basic metadata'))
         self.tabs[0].l = l = QVBoxLayout()
         self.tabs[0].tl = tl = QGridLayout()
         self.tabs[0].setLayout(l)
@@ -987,12 +1006,12 @@ class MetadataSingleDialogAlt1(MetadataSingleDialogBase):  # {{{
 
         self.on_drag_enter.connect(self.handle_drag_enter)
         self.tabs.append(DragTrackingWidget(self, self.on_drag_enter))
-        self.central_widget.addTab(ScrollArea(self.tabs[0], self), _("&Metadata"))
+        self.central_widget.addTab(ScrollArea(self.tabs[0], self), _('&Metadata'))
         self.tabs[0].l = QGridLayout()
         self.tabs[0].setLayout(self.tabs[0].l)
 
         self.tabs.append(QWidget(self))
-        self.central_widget.addTab(ScrollArea(self.tabs[1], self), _("&Cover and formats"))
+        self.central_widget.addTab(ScrollArea(self.tabs[1], self), _('&Cover and formats'))
         self.tabs[1].l = QGridLayout()
         self.tabs[1].setLayout(self.tabs[1].l)
 
@@ -1064,7 +1083,7 @@ class MetadataSingleDialogAlt1(MetadataSingleDialogBase):  # {{{
         sto(self.tags_editor_button, self.publisher_editor_button)
         sto(self.publisher_editor_button, self.paste_isbn_button)
         tl.addItem(QSpacerItem(1, 1, QSizePolicy.Policy.Fixed, QSizePolicy.Policy.Expanding),
-                   13, 1, 1 ,1)
+                   13, 1, 1, 1)
 
         w = getattr(self, 'custom_metadata_widgets_parent', None)
         if w is not None:
@@ -1147,7 +1166,7 @@ class MetadataSingleDialogAlt2(MetadataSingleDialogBase):  # {{{
 
         main_splitter = self.main_splitter = Splitter(Qt.Orientation.Horizontal, self)
         self.central_widget.tabBar().setVisible(False)
-        self.central_widget.addTab(ScrollArea(main_splitter, self), _("&Metadata"))
+        self.central_widget.addTab(ScrollArea(main_splitter, self), _('&Metadata'))
 
         # Left side (metadata & comments)
         # basic and custom split from comments
@@ -1223,7 +1242,7 @@ class MetadataSingleDialogAlt2(MetadataSingleDialogBase):  # {{{
         sto(self.tags_editor_button, self.publisher_editor_button)
         sto(self.publisher_editor_button, self.paste_isbn_button)
         tl.addItem(QSpacerItem(1, 1, QSizePolicy.Policy.Fixed, QSizePolicy.Policy.Expanding),
-                   13, 1, 1 ,1)
+                   13, 1, 1, 1)
 
         # Custom metadata in col 1
         w = getattr(self, 'custom_metadata_widgets_parent', None)
@@ -1328,11 +1347,15 @@ def edit_metadata(db, row_list, current_row, parent=None, view_slot=None, edit_s
     if cls not in editors:
         cls = 'default'
     d = editors[cls](db, parent, editing_multiple=editing_multiple)
+    if hasattr(parent, 'extra_files_watcher'):
+        conn = parent.extra_files_watcher.books_changed.connect(d.update_data_files_button)
     try:
         d.start(row_list, current_row, view_slot=view_slot, edit_slot=edit_slot,
                 set_current_callback=set_current_callback)
         return d.changed, d.rows_to_refresh
     finally:
+        if hasattr(parent, 'extra_files_watcher'):
+            parent.extra_files_watcher.disconnect(conn)
         # possible workaround for bug reports of occasional ghost edit metadata dialog on windows
         d.deleteLater()
 
